# numpretty

Numpretty converts numbers into their human-readable form, efficiently.

## Installation

1. (optional but recommended) Create a venv and activate it: `python3 -m venv env` `env/scripts/activate`

2. Install the package: `pip install numpretty`

## Usage (Example)

```python
import numpretty as npf

print(npf.prettify(1000))
# prints 1K
```